@@ -1,5 +1,4 @@
 /*
- * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -23,7 +22,6 @@
  * @APPLE_LICENSE_HEADER_END@
  */
 
-
 #include <libkern/OSByteOrder.h>
 
 #include <IOKit/IOKitKeys.h>
@@ -212,8 +210,9 @@ AppleUSBHub::start(IOService * provider)
         _resetPortZeroThread = thread_call_allocate((thread_call_func_t)ResetPortZeroEntry, (thread_call_param_t)this);
         _hubDeadCheckThread = thread_call_allocate((thread_call_func_t)CheckForDeadHubEntry, (thread_call_param_t)this);
         _clearFeatureEndpointHaltThread = thread_call_allocate((thread_call_func_t)ClearFeatureEndpointHaltEntry, (thread_call_param_t)this);
+        _clearDevZeroLockThread = thread_call_allocate((thread_call_func_t)ClearDevZeroLockForPort, (thread_call_param_t)this);
         
-        if ( !_workThread || !_resetPortZeroThread || !_hubDeadCheckThread || !_clearFeatureEndpointHaltThread )
+        if ( !_workThread || !_resetPortZeroThread || !_hubDeadCheckThread || !_clearFeatureEndpointHaltThread || !_clearDevZeroLockThread )
         {
             USBError(1, "%s[%p] could not allocate all thread functions.  Aborting start", getName(), this);
             goto ErrorExit;
@@ -314,13 +313,18 @@ AppleUSBHub::stop(IOService * provider)
         thread_call_cancel(_hubDeadCheckThread);
         thread_call_free(_hubDeadCheckThread);
     }
-    
+
     if (_clearFeatureEndpointHaltThread)
     {
         thread_call_cancel(_clearFeatureEndpointHaltThread);
         thread_call_free(_clearFeatureEndpointHaltThread);
     }
-
+    if (_clearDevZeroLockThread)
+    {
+        thread_call_cancel(_clearDevZeroLockThread);
+        thread_call_free(_clearDevZeroLockThread);
+    }
+    
     if (_device)
     {
         // Set it to NULL, since our provider will go away after this stop call
@@ -436,6 +440,9 @@ AppleUSBHub::ConfigureHub()
     
     // after opening the interface, but before we get the pipe, we need to see if this is a 2.0
     // capabale hub, and if so, we need to set the multiTT status if possible
+    _multiTTs = false;
+    _hsHub = false;
+    
     if (_device->GetbcdUSB() >= 0x200)
     {
 	v2Bus = OSDynamicCast(IOUSBControllerV2, _device->GetBus());
@@ -450,10 +457,13 @@ AppleUSBHub::ConfigureHub()
 		case 1:
                     USBLog(5, "%s[%p]::ConfigureHub - found single TT hub", getName(), this);
 		    v2Bus->AddHSHub(_address, 0);
+                    _hsHub = true;
 		    break;
 		    
 		case 2:
                     USBLog(5, "%s[%p]::ConfigureHub - found multi TT hub", getName(), this);
+                    _hsHub = true;
+
 		    if ((err = _hubInterface->SetAlternateInterface(this, 1))) 		// pick the multi-TT setting
 		    {
 			USBError(1, "%s[%p]::ConfigureHub - err (%x) setting alt interface", getName(), this, err);
@@ -461,6 +471,7 @@ AppleUSBHub::ConfigureHub()
 		    }
 		    else
 			v2Bus->AddHSHub(_address, kUSBHSHubFlagsMultiTT);
+			_multiTTs = true;
 		    break;
 		    
 		default:
@@ -812,7 +823,7 @@ AppleUSBHub::HubStatusChanged(void)
         if ((err = GetHubStatus(&_hubStatus)))
         {
             FatalError(err, "get status (first in hub status change)");
-            break;            
+            break;
         }
         _hubStatus.statusFlags = USBToHostWord(_hubStatus.statusFlags);
         _hubStatus.changeFlags = USBToHostWord(_hubStatus.changeFlags);
@@ -821,7 +832,7 @@ AppleUSBHub::HubStatusChanged(void)
 
         if (_hubStatus.changeFlags & kHubLocalPowerStatusChange)
         {
-            USBLog(3, "%s [%p]: Local Power Status Change detected", getName(), this);
+            USBLog(3, "%s [%p]: Hub Local Power Status Change detected", getName(), this);
             if ((err = ClearHubFeature(kUSBHubLocalPowerChangeFeature)))
             {
                 FatalError(err, "clear hub power status feature");
@@ -838,7 +849,7 @@ AppleUSBHub::HubStatusChanged(void)
 
         if (_hubStatus.changeFlags & kHubOverCurrentIndicatorChange)
         {
-            USBLog(3, "%s [%p]: OverCurrent Indicator Change detected", getName(), this);
+            USBLog(3, "%s [%p]: Hub OverCurrent Indicator Change detected", getName(), this);
             if ((err =
                  ClearHubFeature(kUSBHubOverCurrentChangeFeature)))
             {
@@ -853,14 +864,26 @@ AppleUSBHub::HubStatusChanged(void)
             _hubStatus.statusFlags = USBToHostWord(_hubStatus.statusFlags);
             _hubStatus.changeFlags = USBToHostWord(_hubStatus.changeFlags);
         }
-    
-    // See if we have the kResetOnPowerStatusChange errata. This means that upon getting a hub status change, we should do
-    // a device reset
-    //
-    OSBoolean * boolObj = OSDynamicCast( OSBoolean, getProperty("kResetOnPowerStatusChange") );
-    if ( boolObj && boolObj->isTrue() )
-    { 
-        // Reset our hub, as the overcurrent and power status chagnes might disable the ports downstream
+
+        // See if we have the kResetOnPowerStatusChange errata. This means that upon getting a hub status change, we should do
+        // a device reset
+        //
+        OSBoolean * boolObj = OSDynamicCast( OSBoolean, getProperty("kResetOnPowerStatusChange") );
+        if ( boolObj && boolObj->isTrue() )
+        {
+            // Set an error so that we cause our port to be reset. The overcurrent and power status changes might disable the ports downstream
+            // so we need a reset to recover.
+            //
+            err = kIOReturnBusy;
+        }
+
+    } while(false);
+
+    if ( err == kIOReturnSuccess )
+        return true;
+    else
+    {
+        // If we get an error, then we better reset our hub
         //
         _hubIsDead = TRUE;
 
@@ -868,15 +891,12 @@ AppleUSBHub::HubStatusChanged(void)
         ResetMyPort();
         release();
         
-        // Set an error so we return false, which will cause us to NOT rearm the interrupt thread.  The reset
+        // Return false, which will cause us to NOT rearm the interrupt thread.  The reset
         // will take care of reconfiguring the hub and rearming the interrupt.
         //
-        err = kIOReturnBusy;
+        return false;
     }
 
-    } while(false);
-
-    return(err == kIOReturnSuccess);
 }
 
 UInt32 
@@ -1121,7 +1141,7 @@ AppleUSBHub::DoPortAction(UInt32 type, UInt32 portNumber, UInt32 options )
     AppleUSBHubPort 		*port;
     IOReturn			err = kIOReturnSuccess;
 
-    USBLog(5,"+%s[%p]::DoPortAction for port (%d), options (0x%x)", getName(), this, portNumber, options);
+    USBLog(5,"+%s[%p]::DoPortAction(0x%x) for port (%d), options (0x%x)", getName(), this, type, portNumber, options);
 
     if ( _ports == NULL )
         return kIOReturnNoDevice;
@@ -1143,8 +1163,18 @@ AppleUSBHub::DoPortAction(UInt32 type, UInt32 portNumber, UInt32 options )
             case kIOUSBMessageHubResetPort:
                 err = port->ResetPort();
                 break;
+            case kIOUSBMessageHubPortClearTT:
+                // ClearTT is only supported on HS Hubs
+                //
+                if ( _hsHub )
+                    err = port->ClearTT(_multiTTs, options);
+                else
+                    err = kIOReturnUnsupported;
+                break;
         }
     }
+
+    USBLog(5,"-%s[%p]::DoPortAction(0x%x) for port (%d) returning 0x%x",getName(), this, type, portNumber, err);
     
     return err;
 }
@@ -1228,9 +1258,8 @@ AppleUSBHub::InterruptReadHandler(IOReturn status, UInt32 bufferSizeRemaining)
             {
                 USBLog(3, "%s[%p]::InterruptReadHandler Checking to see if hub is still connected", getName(), this);
                 
-                IncrementOutstandingIO();
-                thread_call_enter(_hubDeadCheckThread);
-                
+		CallCheckForDeadHub();
+
                 // Note that since we don't do retries on the Hub, if we get a kIOReturnNotResponding error
                 // we will either determine that the hub is disconnected or we will reset the hub.  In either
                 // case, we will not need to requeue the interrupt, so we don't need to clear the stall.
@@ -1389,7 +1418,7 @@ AppleUSBHub::ProcessStatusChanged()
     bool		hubStatusSuccess = true;
 
     if (isInactive() || !_buffer)
-	return;
+        return;
 
     portMask = 2;
     portByte = 0;
@@ -1442,6 +1471,7 @@ AppleUSBHub::ProcessStatusChanged()
     }
 }
 
+
 IOReturn
 AppleUSBHub::RearmInterruptRead()
 {
@@ -1504,7 +1534,8 @@ AppleUSBHub::message( UInt32 type, IOService * provider,  void * argument )
     IOReturn				err = kIOReturnSuccess;
     IOUSBHubPortStatus			status;
     IOUSBHubPortReEnumerateParam *	params ;
-      
+    IOUSBHubPortClearTTParam *      	ttParams;
+    
     switch ( type )
     {
         case kIOUSBMessageHubIsDeviceConnected:
@@ -1544,6 +1575,11 @@ AppleUSBHub::message( UInt32 type, IOService * provider,  void * argument )
         case kIOUSBMessageHubResetPort:
             err = DoPortAction( type, * (UInt32 *) argument, 0 );
             break;
+
+        case kIOUSBMessageHubPortClearTT:
+            ttParams = (IOUSBHubPortClearTTParam *) argument;
+            err = DoPortAction( type, ttParams->portNumber, ttParams->options );
+            break;
         
         case kIOUSBMessageHubReEnumeratePort:
             params = (IOUSBHubPortReEnumerateParam *) argument;
@@ -1629,23 +1665,13 @@ AppleUSBHub::DoDeviceRequest(IOUSBDevRequest *request)
 {
     IOReturn err;
     
-    // If the device is closed, we should not attempt to send any requests to it
-    //
-    if ( _device && !_device->isOpen(this) )
-    {
-        err = kIOReturnNoDevice;
-        goto exit;
-    }
-    
     // Paranoia:  if we don't have a device ('cause it was stop'ped), then don't send
     // the request.
     //
-    if ( _device )
+    if ( _device && !_device->isInactive() && _device->isOpen(this))
         err = _device->DeviceRequest(request, 5000, 0);
     else
         err = kIOReturnNoDevice;
-
-exit:
         
     return err;
 }
@@ -1718,6 +1744,25 @@ AppleUSBHub::TimeoutOccurred(OSObject *owner, IOTimerEventSource *sender)
 
 }/* end timeoutOccurred */
 
+
+//=============================================================================================
+//
+//  CallCheckForDeadHub
+//  This is called by the hub driver if the interrupt pipe comes back with a NotResponding error
+//  or by the hub port driver if somethine has gone wrong trying to talk to the hub (e.g. a port reset
+//  fails) It increments the IO count and spins off a new thread to actually do the checking
+//
+//=============================================================================================
+//
+void
+AppleUSBHub::CallCheckForDeadHub(void)
+{
+    IncrementOutstandingIO();
+    thread_call_enter(_hubDeadCheckThread);
+}
+
+
+
 //=============================================================================================
 //
 //  CheckForDeadHub is called when we get a kIODeviceNotResponding error in our interrupt pipe.
@@ -1758,7 +1803,7 @@ AppleUSBHub::CheckForDeadHub()
         if ( kIOReturnSuccess == err)
         {
             _hubIsDead = TRUE;
-            USBLog(3, "%s[%p]: Detected an kIONotResponding error but still connected.  Resetting port", getName(), this);
+            USBLog(3, "%s[%p]::CheckForDeadHub - Still connected. Resetting port", getName(), this);
             
             retain();
             ResetMyPort();
@@ -1771,12 +1816,12 @@ AppleUSBHub::CheckForDeadHub()
             // will take care of shutting everything down.  
             //
             _hubHasBeenDisconnected = TRUE;
-            USBLog(3, "%s[%p]: CheckForDeadHub: device has been unplugged", getName(), this);
+            USBLog(3, "%s[%p]::CheckForDeadHub - device has been unplugged", getName(), this);
         }
     }
     else
     {
-        USBLog(3,"%s[%p]: CheckForDeadHub -- already resetting hub",getName(), this);
+        USBLog(3,"%s[%p]::CheckForDeadHub -- already resetting hub",getName(), this);
     }
 
 }
@@ -1840,6 +1885,10 @@ AppleUSBHub::ClearFeatureEndpointHalt( )
 void 
 AppleUSBHub::ResetMyPort()
 {
+    // Call willTerminate on ourselves
+    //
+    willTerminate(this, 0);
+
     // Abort any pending transactions in the interrupt pipe.  Null the pipe because the
     // device reset is going to end up terminating the interface from under us.  (Need 
     // to review that once we change device reset to not terminate interfaces)
@@ -1879,7 +1928,9 @@ AppleUSBHub::requestTerminate( IOService * provider, IOOptionBits options )
 bool
 AppleUSBHub::willTerminate( IOService * provider, IOOptionBits options )
 {
-    IOReturn	err;
+    int			currentPort;
+    AppleUSBHubPort * 	port;
+    IOReturn		err;
     
     USBLog(3, "%s[%p]::willTerminate isInactive = %d", getName(), this, isInactive());
     if ( _interruptPipe )
@@ -1892,7 +1943,26 @@ AppleUSBHub::willTerminate( IOService * provider, IOOptionBits options )
            
 	// _interruptPipe = NULL;
     }
-    
+
+    // JRH 09/19/2003 rdar://problem/3290312
+    // make sure that none of our ports has the dev zero lock held. if they do, it is safe to go ahead
+    // and release it since the hub is now gone (we are terminating)
+    if ( _ports)
+    {
+        for (currentPort = 1; currentPort <= _hubDescriptor.numPorts; currentPort++)
+        {
+            port = _ports[currentPort-1];
+            if (port)
+            {
+                if (port->_devZero)
+                {
+                    USBLog(1, "%s[%p]::StopPorts - port %d had the dev zero lock", getName(), this, currentPort);
+                }
+                thread_call_enter1(_clearDevZeroLockThread, (thread_call_param_t) port);
+            }
+        }
+    }
+
     // We are going to be terminated, so clean up! Make sure we don't get any more status change interrupts.
     // Note that if we are terminated before we set up our interrupt pipe, then we better not call it!
     //
@@ -2034,3 +2104,22 @@ AppleUSBHub::ChangeOutstandingIO(OSObject *target, void *param1, void *param2, v
 }
 
 
+
+//=============================================================================================
+//
+//  ClearDevZeroLockForPort
+//
+//=============================================================================================
+//
+void
+AppleUSBHub::ClearDevZeroLockForPort(OSObject *target, thread_call_param_t thePort)
+{
+    AppleUSBHub *	me = OSDynamicCast(AppleUSBHub, target);
+    AppleUSBHubPort *	port = (AppleUSBHubPort *) thePort;
+
+    if (!me || !port)
+        return;
+
+    port->willTerminate(me, 0);
+}
+
