@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1998-2002 Apple Computer, Inc. All rights reserved.
+ * Copyright (c) 1998-2003 Apple Computer, Inc. All rights reserved.
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
@@ -244,7 +244,7 @@ AppleUSBMouse::start(IOService * provider)
             locationID = locationIDProperty->unsigned32BitValue();
         }
 
-        USBLog(1, "%s[%p]::start USB Generic Mouse @ %d (0x%x)", getName(), this, _device->GetAddress(), locationID);
+        USBError(1, "%s[%p]::start USB Generic Mouse @ %d (0x%x)", getName(), this, _device->GetAddress(), locationID);
 
 	// OK- so this is not totally kosher in the IOKit world. You are supposed to call super::start near the BEGINNING
 	// of your own start method. However, the IOHIPointing::start method invokes registerService, which we don't want to
@@ -1123,7 +1123,6 @@ AppleUSBMouse::terminate( IOOptionBits options = 0 )
 void
 AppleUSBMouse::free( void )
 {
-    USBLog(3, "%s[%p]::free isInactive = %d", getName(), this, isInactive());
     super::free();
 }
 
